==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/theme.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

$VAR['Content'] = "";
sort($CONF['active_theme']);
$VAR['Content'] = "<CENTER>".
                "<FORM METHOD=\"POST\" ACTION=\"". 
                $_SERVER['PHP_SELF'] ."?". $_SERVER['QUERY_STRING'] 
                ."\">".
                "<SELECT ONCHANGE=\"submit()\" NAME=\"korweblog_new_theme\">";
foreach($CONF['active_theme'] as $val) {
   $VAR['Content'] .= "<OPTION VALUE=\"$val\"". ($val == $site_theme ? " SELECTED" : "") ."> $val";
}
$VAR['Content'] .= "</SELECT>".
                 "<INPUT TYPE=\"submit\" VALUE=\"Ok\">".
                 "</FORM></CENTER>";

$VAR['Display'] =& $align;
$VAR['Heading'] = _THEME_USE;
KWL_DrawBlock($VAR);
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/theme.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

$VAR['Content'] = "";
sort($CONF['active_theme']);
$VAR['Content'] = "<center>".
                "<form method=\"post\" action=\"". 
                $_SERVER['PHP_SELF'] ."?". $_SERVER['QUERY_STRING'] 
                ."\">".
                "<select onchange=\"submit()\" name=\"korweblog_new_theme\">";
foreach($CONF['active_theme'] as $val) {
   $VAR['Content'] .= "<option value=\"$val\"". ($val == $site_theme ? " selected=\"selected\"" : "") ."> $val</option>";
}
$VAR['Content'] .= "</select>".
                 "<input type=\"submit\" value=\"Ok\" />".
                 "</form></center>";

$VAR['Display'] =& $align;
$VAR['Heading'] = _THEME_USE;
KWL_DrawBlock($VAR);
?>
